@@ -1252,88 +1252,88 @@ gnumeric_invsuminv (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 
 GnmFuncDescriptor const engineering_functions[] = {
         { "base",     "Sf|f",    help_base,
-	  gnumeric_base, NULL, NULL, NULL, NULL,
+	  gnumeric_base, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         { "besseli",     "ff",    help_besseli,
-	  gnumeric_besseli, NULL, NULL, NULL, NULL,
+	  gnumeric_besseli, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "besselj",     "ff",    help_besselj,
-	  gnumeric_besselj, NULL, NULL, NULL, NULL,
+	  gnumeric_besselj, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "besselk",     "ff",    help_besselk,
-	  gnumeric_besselk, NULL, NULL, NULL, NULL,
+	  gnumeric_besselk, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "bessely",     "ff",    help_bessely,
-	  gnumeric_bessely, NULL, NULL, NULL, NULL,
+	  gnumeric_bessely, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "bin2dec",     "S",     help_bin2dec,
-	  gnumeric_bin2dec, NULL, NULL, NULL, NULL,
+	  gnumeric_bin2dec, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "bin2hex",     "S|f",   help_bin2hex,
-	  gnumeric_bin2hex, NULL, NULL, NULL, NULL,
+	  gnumeric_bin2hex, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "bin2oct",     "S|f",   help_bin2oct,
-	  gnumeric_bin2oct, NULL, NULL, NULL, NULL,
+	  gnumeric_bin2oct, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "convert",     "fss",   help_convert,
-	  gnumeric_convert, NULL, NULL, NULL, NULL,
+	  gnumeric_convert, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "dec2bin",     "S|f",   help_dec2bin,
-	  gnumeric_dec2bin, NULL, NULL, NULL, NULL,
+	  gnumeric_dec2bin, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "dec2oct",     "S|f",   help_dec2oct,
-	  gnumeric_dec2oct, NULL, NULL, NULL, NULL,
+	  gnumeric_dec2oct, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "dec2hex",     "S|f",   help_dec2hex,
-	  gnumeric_dec2hex, NULL, NULL, NULL, NULL,
+	  gnumeric_dec2hex, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "decimal",     "Sf",    help_decimal,
-	  gnumeric_decimal, NULL, NULL, NULL, NULL,
+	  gnumeric_decimal, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         { "delta",       "f|f",   help_delta,
-	  gnumeric_delta, NULL, NULL, NULL, NULL,
+	  gnumeric_delta, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "erf",         "f|f",   help_erf,
-	  gnumeric_erf , NULL, NULL, NULL, NULL,
+	  gnumeric_erf , NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "erfc",        "f",     help_erfc,
-	  gnumeric_erfc, NULL, NULL, NULL, NULL,
+	  gnumeric_erfc, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "gestep",      "f|f",   help_gestep,
-	  gnumeric_gestep, NULL, NULL, NULL, NULL,
+	  gnumeric_gestep, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "hex2bin",     "S|f",   help_hex2bin,
-	  gnumeric_hex2bin, NULL, NULL, NULL, NULL,
+	  gnumeric_hex2bin, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "hex2dec",     "S",     help_hex2dec,
-	  gnumeric_hex2dec, NULL, NULL, NULL, NULL,
+	  gnumeric_hex2dec, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "hex2oct",     "S|f",   help_hex2oct,
-	  gnumeric_hex2oct, NULL, NULL, NULL, NULL,
+	  gnumeric_hex2oct, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         { "hexrep",     "f",   help_hexrep,
-	  gnumeric_hexrep, NULL, NULL, NULL, NULL,
+	  gnumeric_hexrep, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
 	{ "invsuminv",    NULL,            help_invsuminv,
-	  NULL, gnumeric_invsuminv, NULL, NULL, NULL,
+	  NULL, gnumeric_invsuminv, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 
         { "oct2bin",     "S|f",   help_oct2bin,
-	  gnumeric_oct2bin, NULL, NULL, NULL, NULL,
+	  gnumeric_oct2bin, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "oct2dec",     "S",     help_oct2dec,
-	  gnumeric_oct2dec, NULL, NULL, NULL, NULL,
+	  gnumeric_oct2dec, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
         { "oct2hex",     "S|f",   help_oct2hex,
-	  gnumeric_oct2hex, NULL, NULL, NULL, NULL,
+	  gnumeric_oct2hex, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
         {NULL}
