@@ -133,7 +133,10 @@ gnm_cell_assign_value (GnmCell *cell, GnmValue *v)
 }
 
 /**
- * gnm_cell_set_value: Stores (WITHOUT COPYING) the supplied value.  It marks the
+ * gnm_cell_set_value:
+ * @c: #GnmCell
+ * @v: #GnmValue
+ * Stores (WITHOUT COPYING) the supplied value.  It marks the
  *          sheet as dirty.
  *
  * WARNING : This is an internal routine that does not
@@ -362,11 +365,12 @@ gnm_cell_set_array_formula_undo (GnmSheetRange *sr, GnmExprTop const  *texpr)
 }
 
 /**
- * gnm_cell_set_array: set an array expression for a range.
+ * gnm_cell_set_array:
  * @sheet:   The sheet to set the expr in.
  * @r:       The range to set.
  * @texpr:   an expression (the inner expression, not a corner or element)
  *
+ * Set an array expression for a range.
  * Uses cell_set_expr_internal to store the expr as an
  * 'array-formula'.  The supplied expression is wrapped in an array
  * operator for each cell in the range and scheduled for recalc.
@@ -912,6 +916,35 @@ gnm_cell_get_style (GnmCell const *cell)
 				cell->pos.row);
 }
 
+/**
+ * gnm_cell_get_format_given_style:
+ * @cell:
+ * @style:
+ *
+ * Get the display format.  If the assigned format is General,
+ * the format of the value will be used.
+ **/
+GOFormat const *
+gnm_cell_get_format_given_style (GnmCell const *cell, GnmStyle const *style)
+{
+	GOFormat const *fmt;
+
+	g_return_val_if_fail (cell != NULL, go_format_general ());
+
+	if (style == NULL)
+		style = gnm_cell_get_style (cell);
+
+	fmt = gnm_style_get_format (style);
+
+	g_return_val_if_fail (fmt != NULL, go_format_general ());
+
+	if (go_format_is_general (fmt) &&
+	    cell->value != NULL && VALUE_FMT (cell->value))
+		fmt = VALUE_FMT (cell->value);
+
+	return fmt;
+}
+
 /**
  * gnm_cell_get_format:
  * @cell:
@@ -922,19 +955,7 @@ gnm_cell_get_style (GnmCell const *cell)
 GOFormat const *
 gnm_cell_get_format (GnmCell const *cell)
 {
-	GOFormat const *fmt;
-
-	g_return_val_if_fail (cell != NULL, go_format_general ());
-
-	fmt = gnm_style_get_format (gnm_cell_get_style (cell));
-
-	g_return_val_if_fail (fmt != NULL, go_format_general ());
-
-	if (go_format_is_general (fmt) &&
-	    cell->value != NULL && VALUE_FMT (cell->value))
-		fmt = VALUE_FMT (cell->value);
-
-	return fmt;
+	gnm_cell_get_format_given_style (cell, NULL);	
 }
 
 /*
