@@ -44,6 +44,7 @@
 #include <commands.h>
 #include <clipboard.h>
 #include <selection.h>
+#include <application.h>
 #include <tools/gnm-solver.h>
 #include <widgets/gnumeric-expr-entry.h>
 
@@ -677,7 +678,7 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	dialog = (GtkDialog *)gtk_dialog_new_with_buttons
 		(_("Running Solver"),
 		 wbcg_toplevel (state->wbcg), 0,
-		 NULL);
+		 NULL, NULL);
 	state->run.stop_button =
 		go_gtk_dialog_add_button (dialog,
 					  _("Stop"),
@@ -924,7 +925,7 @@ cb_dialog_solve_clicked (G_GNUC_UNUSED GtkWidget *button,
 
 	res = run_solver (state, param);
 
-	workbook_recalc (state->sheet->workbook);
+	gnm_app_recalc ();
 
 	if (res != NULL) {
 		if ((res->quality == GNM_SOLVER_RESULT_OPTIMAL ||
@@ -977,7 +978,7 @@ dialog_init (SolverState *state)
 
 	param = state->sheet->solver_parameters;
 
-	state->gui = gnm_gtk_builder_new ("solver.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
+	state->gui = gnm_gtk_builder_load ("solver.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
         if (state->gui == NULL)
                 return TRUE;
 
