@@ -95,7 +95,7 @@ gui_wb_view_show (WBCGtk *wbcg, WorkbookView *wbv)
 	} else {
 		GdkScreen *screen = gtk_window_get_screen (wbcg_toplevel (wbcg));
 		WorkbookControl *new_wbc =
-			wb_control_wrapper_new (WORKBOOK_CONTROL (wbcg),
+			workbook_control_new_wrapper (WORKBOOK_CONTROL (wbcg),
 						wbv, NULL, screen);
 		new_wbcg = WBC_GTK (new_wbc);
 
@@ -114,7 +114,7 @@ gui_file_read (WBCGtk *wbcg, char const *uri,
 
 	go_cmd_context_set_sensitive (GO_CMD_CONTEXT (wbcg), FALSE);
 	io_context = go_io_context_new (GO_CMD_CONTEXT (wbcg));
-	wbv = wb_view_new_from_uri (uri, optional_format, io_context,
+	wbv = workbook_view_new_from_uri (uri, optional_format, io_context,
 				    optional_encoding);
 
 	if (go_io_error_occurred (io_context) ||
@@ -126,7 +126,7 @@ gui_file_read (WBCGtk *wbcg, char const *uri,
 
 	if (wbv != NULL) {
 		gui_wb_view_show (wbcg, wbv);
-		workbook_update_history (wb_view_get_workbook (wbv));
+		workbook_update_history (wb_view_get_workbook (wbv), FILE_SAVE_AS_SAVE);
 		return TRUE;
 	}
 	return FALSE;
@@ -142,7 +142,7 @@ gui_file_template (WBCGtk *wbcg, char const *uri)
 
 	go_cmd_context_set_sensitive (GO_CMD_CONTEXT (wbcg), FALSE);
 	io_context = go_io_context_new (GO_CMD_CONTEXT (wbcg));
-	wbv = wb_view_new_from_uri (uri, optional_format, io_context,
+	wbv = workbook_view_new_from_uri (uri, optional_format, io_context,
 				    optional_encoding);
 
 	if (go_io_error_occurred (io_context) ||
@@ -581,16 +581,21 @@ gui_file_save_as (WBCGtk *wbcg, WorkbookView *wb_view, file_save_as_t type,
 		if (!fs || g_list_find (savers, fs) == NULL)
 			fs = go_file_saver_get_default ();
 	} else {
-		fs = workbook_get_file_exporter (wb);
+		if (default_format)
+			fs = go_file_saver_for_id (default_format);
+		else
+			fs = workbook_get_file_exporter (wb);
 		if (!fs || g_list_find (savers, fs) == NULL)
-			fs = go_file_saver_for_id (default_format ? default_format
-						   : "Gnumeric_html:latex_table");
+			fs = go_file_saver_for_id ("Gnumeric_html:latex_table");
 	}
 
 	gtk_combo_box_set_active (format_combo, g_list_index (savers, fs));
 
 	/* Set default file name */
-	wb_uri = go_doc_get_uri (GO_DOC (wb));
+	if (!(wb_uri = workbook_get_last_export_uri (wb)) || (type != FILE_SAVE_AS_EXPORT)
+	    || (fs !=  workbook_get_file_exporter (wb)))
+		wb_uri = go_doc_get_uri (GO_DOC (wb));
+
 	if (wb_uri != NULL) {
 		char *basename = go_basename_from_uri (wb_uri);
 		char *dot = basename ? strrchr (basename, '.') : NULL;
@@ -653,7 +658,7 @@ gui_file_save_as (WBCGtk *wbcg, WorkbookView *wb_view, file_save_as_t type,
 		gtk_widget_destroy (GTK_WIDGET (fsel));
 		fsel = NULL;
 		if (wb_view_save_as (wb_view, fs, uri, GO_CMD_CONTEXT (wbcg)))
-			workbook_update_history (wb);
+			workbook_update_history (wb, type);
 	}
 
 	g_free (uri);
@@ -693,8 +698,59 @@ gui_file_save (WBCGtk *wbcg, WorkbookView *wb_view)
 
 		ok = wb_view_save (wb_view, GO_CMD_CONTEXT (wbcg));
 		if (ok)
-			workbook_update_history (wb);
+			workbook_update_history (wb, FILE_SAVE_AS_SAVE);
 		g_object_unref (wb);
 		return ok;
 	}
 }
+
+gboolean
+gui_file_export_repeat (WBCGtk *wbcg)
+{
+	WorkbookView *wb_view = wb_control_view (WORKBOOK_CONTROL (wbcg));
+	Workbook *wb = wb_view_get_workbook (wb_view);
+	GOFileSaver *fs = workbook_get_file_exporter (wb);
+	gchar const *last_uri = workbook_get_last_export_uri (wb);
+
+	if (fs != NULL && last_uri != NULL) {
+		char const *msg;
+		GtkWidget *dialog;
+
+		if (go_file_saver_get_save_scope (fs) != GO_FILE_SAVE_WORKBOOK)
+			msg = _("Do you want to export the <b>current sheet</b> of this "
+				"workbook to the location '<b>%s</b>' "
+				"using the '<b>%s</b>' exporter?");
+		else
+			msg = _("Do you want to export this workbook to the "
+				"location '<b>%s</b>' "
+				"using the '<b>%s</b>' exporter?");
+
+		/* go_gtk_query_yes_no does not handle markup ... */
+		dialog = gtk_message_dialog_new_with_markup (wbcg_toplevel (wbcg),
+							     GTK_DIALOG_DESTROY_WITH_PARENT,
+							     GTK_MESSAGE_QUESTION,
+							     GTK_BUTTONS_YES_NO,
+							     msg, last_uri,
+							     go_file_saver_get_description (fs));
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
+
+		if (GTK_RESPONSE_YES ==
+		    go_gtk_dialog_run (GTK_DIALOG (dialog), wbcg_toplevel (wbcg))) {
+			/* We need to copy wb->last_export_uri since it will be reset during saving */
+			gchar *uri = g_strdup (last_uri);
+			if(wb_view_save_as (wb_view, fs, uri, GO_CMD_CONTEXT (wbcg))) {
+				workbook_update_history (wb, FILE_SAVE_AS_EXPORT);
+				g_free (uri);
+				return TRUE;
+			}
+			g_free (uri);
+		}
+		return FALSE;
+	} else {
+		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
+				      _("Unable to repeat export since no previous "
+					"export information has been saved in this "
+					"session."));
+		return FALSE;
+	}
+}
