@@ -26,6 +26,12 @@ gnm_range_count (G_GNUC_UNUSED gnm_float const *xs, int n, gnm_float *res)
 int
 gnm_range_hypot (gnm_float const *xs, int n, gnm_float *res)
 {
+	/* Drop outside zeros because the n<=2 cases are more accurate.  */
+	while (n > 0 && xs[0] == 0)
+		xs++, n--;
+	while (n > 0 && xs[n - 1] == 0)
+		n--;
+
 	switch (n) {
 	case 0: *res = 0; return 0;
 	case 1: *res = gnm_abs (xs[0]); return 0;
@@ -449,8 +455,8 @@ gnm_range_mode (gnm_float const *xs, int n, gnm_float *res)
 	return 0;
 }
 
-int 
-gnm_range_adtest    (gnm_float const *xs, int n, gnm_float *pvalue, 
+int
+gnm_range_adtest    (gnm_float const *xs, int n, gnm_float *pvalue,
 		     gnm_float *statistics)
 {
 	gnm_float mu = 0.;
@@ -468,8 +474,8 @@ gnm_range_adtest    (gnm_float const *xs, int n, gnm_float *pvalue,
 		ys = range_sort (xs, n);
 
 		for (i = 0; i < n; i++) {
-			gnm_float val = (pnorm (ys[i], mu, sigma, TRUE, TRUE) + 
-					 pnorm (ys[n - i - 1], 
+			gnm_float val = (pnorm (ys[i], mu, sigma, TRUE, TRUE) +
+					 pnorm (ys[n - i - 1],
 						mu, sigma, FALSE, TRUE));
 			total += ((2*i+1)* val);
 		}
