@@ -217,7 +217,7 @@ gnm_search_collect_cells (GnmSearchReplace *sr)
 		break;
 
 	case GNM_SRS_SHEET:
-		cells = sheet_cells (sr->sheet, TRUE);
+		cells = sheet_cell_positions (sr->sheet, TRUE);
 		break;
 
 	case GNM_SRS_RANGE:
