@@ -190,9 +190,9 @@ value_error_name (GnmStdError err, gboolean translated)
 }
 
 /**
- * value_error_set_pos :
- * @err :
- * @pos :
+ * value_error_set_pos:
+ * @err:
+ * @pos:
  *
  * Change the position of a ValueError.
  */
@@ -263,7 +263,7 @@ value_new_cellrange_unsafe (GnmCellRef const *a, GnmCellRef const *b)
 }
 
 /**
- * value_new_cellrange : Create a new range reference.
+ * value_new_cellrange: Create a new range reference.
  *
  * Attempt to do a sanity check for inverted ranges.
  * NOTE : This is no longer necessary and will be removed.
@@ -341,7 +341,7 @@ value_new_cellrange_r (Sheet *sheet, GnmRange const *r)
 }
 
 /**
- * value_new_cellrange_str :
+ * value_new_cellrange_str:
  * @sheet: the sheet where the cell range is evaluated. This really only needed if
  *         the range given does not include a sheet specification.
  * @str: a range specification (ex: "A1", "A1:C3", "Sheet1!A1:C3", "R1C1").
@@ -365,7 +365,7 @@ value_new_cellrange_str (Sheet *sheet, char const *str)
 }
 
 /**
- * value_new_cellrange_parsepos_str :
+ * value_new_cellrange_parsepos_str:
  * @pp:  if a relative range is specified, then it will be interpreted relative
  *       to this position (affects only A1-style relative references).
  * @str: a range specification (ex: "A1", "A1:C3", "Sheet1!A1:C3", "R1C1").
@@ -595,10 +595,10 @@ value_release (GnmValue *value)
 }
 
 /**
- * value_dup :
- * @src : #GnmValue
+ * value_dup:
+ * @v: #GnmValue
  *
- * Returns a copy of @src.  @src == NULL will return NULL
+ * Returns a copy of @v.  @v == NULL will return NULL
  **/
 GnmValue *
 value_dup (GnmValue const *src)
@@ -665,9 +665,9 @@ value_compare_real (GnmValue const *a, GnmValue const *b,
 
 
 /**
- * value_cmp :
- * @ptr_a :
- * @ptr_b :
+ * value_cmp:
+ * @ptr_a:
+ * @ptr_b:
  *
  * qsort style comparison function.
  **/
@@ -849,9 +849,9 @@ value_get_as_checked_bool (GnmValue const *v)
 
 /**
  * value_get_as_gstring:
- * @v : #GnmValue
- * @target : #GString
- * @conv : #GnmConventions
+ * @v: #GnmValue
+ * @target: #GString
+ * @conv: #GnmConventions
  *
  * A simple value formatter to convert @v into a string stored in @target
  * according to @conv.  See format_value_gstring for something more elaborate
@@ -959,8 +959,8 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 
 
 /**
- * value_get_as_string :
- * @v :
+ * value_get_as_string:
+ * @v:
  *
  * simplistic value rendering
  *
@@ -1091,9 +1091,9 @@ value_get_rangeref (GnmValue const *v)
 
 
 /**
- * value_coerce_to_number :
- * @v :
- * @valid :
+ * value_coerce_to_number:
+ * @v:
+ * @valid:
  *
  * If the value can be used as a number return that number
  * otherwise free it at return an appropriate error
@@ -1162,10 +1162,10 @@ compare_float_float (GnmValue const *va, GnmValue const *vb)
 }
 
 /**
- * value_diff :
+ * value_diff:
  *
- * @a : value a
- * @b : value b
+ * @a: value a
+ * @b: value b
  *
  * IGNORES format.
  *
@@ -1270,11 +1270,11 @@ gnm_string_cmp_ignorecase (gconstpointer gstr_a, gconstpointer gstr_b)
 
 
 /**
- * value_compare :
+ * value_compare:
  *
- * @a : value a
- * @b : value b
- * @case_sensitive : are string comparisons case sensitive.
+ * @a: value a
+ * @b: value b
+ * @case_sensitive: are string comparisons case sensitive.
  *
  * IGNORES format.
  */
@@ -1628,13 +1628,38 @@ find_column_of_field (GnmEvalPos const *ep,
 void
 free_criteria (GnmCriteria *criteria)
 {
+	if (!criteria || criteria->ref_count-- > 1)
+		return;
 	value_release (criteria->x);
 	if (criteria->has_rx)
 		go_regfree (&criteria->rx);
 	g_free (criteria);
 }
 
-/*
+static GnmCriteria *
+gnm_criteria_ref (GnmCriteria *criteria)
+{
+	criteria->ref_count++;
+	return criteria;
+}
+
+GType
+gnm_criteria_get_type (void)
+{
+	static GType t = 0;
+
+	if (t == 0) {
+		t = g_boxed_type_register_static ("GnmCriteria",
+			 (GBoxedCopyFunc)gnm_criteria_ref,
+			 (GBoxedFreeFunc)free_criteria);
+	}
+	return t;
+}
+
+/**
+ * free_criterias:
+ * @criterias: (element-type GnmCriteria) (transfer full): the criteria to be
+ * freed.
  * Frees the allocated memory.
  */
 void
@@ -1653,11 +1678,11 @@ free_criterias (GSList *criterias)
 }
 
 /**
- * parse_criteria :
- * @crit_val : #GnmValue
- * @date_conv : #GODateConventions
+ * parse_criteria:
+ * @crit_val: #GnmValue
+ * @date_conv: #GODateConventions
  *
- * Returns GnmCriteria which caller must free.
+ * Returns: (transfer full): GnmCriteria which caller must free.
  *
  * ">=value"
  * "<=value"
@@ -1719,6 +1744,7 @@ parse_criteria (GnmValue const *crit_val, GODateConventions const *date_conv)
 	if (res->fun (empty, res))
 		res->iter_flags &= ~CELL_ITER_IGNORE_BLANK;
 	value_release (empty);
+	res->ref_count = 1;
 
 	return res;
 }
@@ -1759,8 +1785,14 @@ parse_criteria_range (Sheet *sheet, int b_col, int b_row, int e_col, int e_row,
 	return g_slist_reverse (criterias);
 }
 
-/*
+/**
+ * parse_database_criteria:
+ * @ep: #GnmEvalPos
+ * @database: #GnmValue
+ * @criteria: #GnmValue
+ *
  * Parses the criteria cell range.
+ * Returns: (element-type GnmDBCriteria) (transfer full):
  */
 GSList *
 parse_database_criteria (GnmEvalPos const *ep, GnmValue const *database, GnmValue const *criteria)
@@ -1804,8 +1836,19 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue const *database, GnmValu
 				     e_col, e_row, field_ind);
 }
 
-/* Finds the rows from the given database that match the criteria.
- */
+/**
+ * find_rows_that_match:
+ * @sheet: #Sheet
+ * @first_col: first column.
+ * @first_row: first row.
+ * @last_col: last column.
+ * @last_row: laset row.
+ * @criterias: (element-type GnmDBCriteria): the criteria to use.
+ * @unique_only:
+ *
+ * Finds the rows from the given database that match the criteria.
+ * Returns: (element-type int) (transfer full): the list of matching rows. 
+ **/
 GSList *
 find_rows_that_match (Sheet *sheet, int first_col, int first_row,
 		      int last_col, int last_row,
